#! /bin/bash

. /opt/artixcs-mysql-dump/artixcs-mysql-dump.conf

echo "user=$user"
echo "passwd=$passwd"
echo "backupDir=$backupDir"
echo "useCompress=$useCompress"

fullBackupDir=${backupDir}/full

if [[ -d "${fullBackupDir}" ]] && [[ "$(ls -A ${fullBackupDir})" ]]; then

    # найдем все инкрементальные бэкапы
    incrementDirs=()
    while IFS=  read -r -d $'\0'; do
        incrementDirs+=("$REPLY")
    done < <(find ${backupDir} -maxdepth 1 -name 'increment*' -type d -print0)

    # если используется сжатие бэкапов, то надо разархивировать
    if [[ "$useCompress" = 'true' ]]; then
        echo "decompress ${fullBackupDir}"
        xtrabackup --decompress --remove-original --parallel=4 --target-dir=${fullBackupDir}
        for incrementDir in ${incrementDirs[@]}; do
            echo "decompress $incrementDir"
            xtrabackup --decompress --remove-original --parallel=4 --target-dir=$incrementDir
        done
    fi;

    # получим последний инкрементальный бэкап
    lastIncrementDir=$(find ${backupDir} -maxdepth 1 -name 'increment*' -type d | sort -n | tail -1)

    # отсортируем инкрементальные бэкапы
    readarray -t incrementDirsSorted < <(printf '%s\0' "${incrementDirs[@]}" | sort -z | xargs -0n1)

    # подготовка бэкапов к развертыванию
    echo "--prepare ${fullBackupDir}"
    xtrabackup --prepare --apply-log-only --target-dir=${fullBackupDir}
    for incrementDir in ${incrementDirsSorted[@]}; do
        echo "prepare $incrementDir"
        if [[ "$lastIncrementDir" = "$incrementDir" ]]; then
            xtrabackup --prepare --target-dir=${fullBackupDir} --incremental-dir=$incrementDir
        else
            xtrabackup --prepare --apply-log-only --target-dir=${fullBackupDir} --incremental-dir=$incrementDir
        fi
    done

    # для ускорения запуска сервера при восстановлении с бекапа
    xtrabackup --prepare --target-dir=${fullBackupDir}

    # останавливаем mysql, переносим в бэкапы рабочую директорияю mysql, восстанавливаем бэкап и запускаем mysql
    oldMysqlDir=${backupDir}/old_mysql_$(date +%y%m%d%H%M%S)
    service mysql stop
    rm -rf ${oldMysqlDir}
    mkdir -p ${oldMysqlDir}
    mv  /var/lib/mysql ${oldMysqlDir}
    mkdir  /var/lib/mysql
    xtrabackup --copy-back --target-dir=${fullBackupDir}
    chown -R mysql:mysql /var/lib/mysql
    service mysql start

fi


